Learn R Programming

validatedb (version 0.1.4)

rule_works_on_tbl: tests for each rule if it can be executed on the database

Description

tests for each rule if it can be executed on the database

Usage

rule_works_on_tbl(tbl, x)

Arguments

tbl

a tbl object with columns used in x

Value

logical encoding which validation rules "work" on the database.